SCTP: plug the remaining memleaks in the tap
[metze/wireshark/wip.git] / dftest.c
index bb941ea994b49beca7049710150b18a087112bc4..e6e09b41e1945b604558de74024cf6663f213047 100644 (file)
--- a/dftest.c
+++ b/dftest.c
@@ -5,19 +5,7 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include <config.h>
 #include <epan/prefs.h>
 #include <epan/dfilter/dfilter.h>
 
+#ifdef HAVE_PLUGINS
 #include <wsutil/plugins.h>
+#endif
 #include <wsutil/filesystem.h>
 #include <wsutil/privileges.h>
-#include <wsutil/report_err.h>
+#include <wsutil/report_message.h>
+
+#include <wiretap/wtap.h>
 
 #include "ui/util.h"
-#include "register.h"
+#include "epan/register.h"
 
-static void failure_message(const char *msg_format, va_list ap);
+static void failure_warning_message(const char *msg_format, va_list ap);
 static void open_failure_message(const char *filename, int err,
        gboolean for_writing);
 static void read_failure_message(const char *filename, int err);
@@ -54,10 +46,8 @@ main(int argc, char **argv)
 {
        char            *init_progfile_dir_error;
        char            *text;
-       char            *gpf_path, *pf_path;
-       int             gpf_open_errno, gpf_read_errno;
-       int             pf_open_errno, pf_read_errno;
        dfilter_t       *df;
+       gchar           *err_msg;
 
        /*
         * Get credential information for later use.
@@ -65,56 +55,38 @@ main(int argc, char **argv)
        init_process_policies();
 
        /*
* Attempt to get the pathname of the executable file.
         */
-       init_progfile_dir_error = init_progfile_dir(argv[0], main);
+       init_progfile_dir_error = init_progfile_dir(argv[0]);
        if (init_progfile_dir_error != NULL) {
-               fprintf(stderr, "dftest: Can't get pathname of dftest program: %s.\n",
+               fprintf(stderr, "dftest: Can't get pathname of directory containing the dftest program: %s.\n",
                        init_progfile_dir_error);
+               g_free(init_progfile_dir_error);
        }
 
-       init_report_err(failure_message, open_failure_message,
-                       read_failure_message, write_failure_message);
+       init_report_message(failure_warning_message, failure_warning_message,
+                           open_failure_message, read_failure_message,
+                           write_failure_message);
 
        timestamp_set_type(TS_RELATIVE);
        timestamp_set_seconds_type(TS_SECONDS_DEFAULT);
 
+       wtap_init(TRUE);
+
        /* Register all dissectors; we must do this before checking for the
           "-g" flag, as the "-g" flag dumps a list of fields registered
           by the dissectors, and we must do it before we read the preferences,
           in case any dissectors register preferences. */
-       epan_init(register_all_protocols, register_all_protocol_handoffs,
-                 NULL, NULL);
+       if (!epan_init(register_all_protocols, register_all_protocol_handoffs,
+           NULL, NULL))
+               return 2;
 
        /* set the c-language locale to the native environment. */
        setlocale(LC_ALL, "");
 
-       read_prefs(&gpf_open_errno, &gpf_read_errno, &gpf_path,
-               &pf_open_errno, &pf_read_errno, &pf_path);
-       if (gpf_path != NULL) {
-               if (gpf_open_errno != 0) {
-                       fprintf(stderr,
-                               "can't open global preferences file \"%s\": %s.\n",
-                               pf_path, g_strerror(gpf_open_errno));
-               }
-               if (gpf_read_errno != 0) {
-                       fprintf(stderr,
-                               "I/O error reading global preferences file \"%s\": %s.\n",
-                               pf_path, g_strerror(gpf_read_errno));
-               }
-       }
-       if (pf_path != NULL) {
-               if (pf_open_errno != 0) {
-                       fprintf(stderr,
-                               "can't open your preferences file \"%s\": %s.\n",
-                               pf_path, g_strerror(pf_open_errno));
-               }
-               if (pf_read_errno != 0) {
-                       fprintf(stderr,
-                               "I/O error reading your preferences file \"%s\": %s.\n",
-                               pf_path, g_strerror(pf_read_errno));
-               }
-       }
+       /* Load libwireshark settings from the current profile. */
+       epan_load_settings();
 
        /* notify all registered modules that have had any of their preferences
        changed either from one of the preferences file or from the command
@@ -133,8 +105,9 @@ main(int argc, char **argv)
        printf("Filter: \"%s\"\n", text);
 
        /* Compile it */
-       if (!dfilter_compile(text, &df)) {
-               fprintf(stderr, "dftest: %s\n", dfilter_error_msg);
+       if (!dfilter_compile(text, &df, &err_msg)) {
+               fprintf(stderr, "dftest: %s\n", err_msg);
+               g_free(err_msg);
                epan_cleanup();
                exit(2);
        }
@@ -152,10 +125,11 @@ main(int argc, char **argv)
 }
 
 /*
- * General errors are reported with an console message in "dftest".
+ * General errors and warnings are reported with an console message
+ * in "dftest".
  */
 static void
-failure_message(const char *msg_format, va_list ap)
+failure_warning_message(const char *msg_format, va_list ap)
 {
        fprintf(stderr, "dftest: ");
        vfprintf(stderr, msg_format, ap);
@@ -65,56 +55,38 @@ main(int argc, char **argv)
 
        /*
-        * Attempt to get the pathname of the executable file.
+        * Attempt to get the pathname of the directory containing the
+        * executable file.
         */